# frozen_string_literal: true

require 'base64'
require 'codat/version'
require 'codat/errors'

module Codat
  class FaradayCodatAuth < Faraday::Middleware
    def initialize(app, api_key = '', options = {})
      @app = app
      @api_key = api_key
      @options = options
    end

    def call(env)
      unless @api_key&.size&.positive?
        raise APIKeyError, 'Missing api_key! Use a Codat.configure block to add your key.'
      end

      env[:request_headers]['Authorization'] = "Basic #{Base64.encode64(@api_key)}"
      env[:request_headers]['Content-Type'] = 'application/json'
      env[:request_headers]['User-Agent'] = "finpoint/#{Codat::VERSION}"

      @app.call(env)
    end
  end
end
